%global tarname  igt-gpu-tools

# note: FC named this package as igt-gpu-tools

Name:           intel-gpu-tools
Version:        1.30
Release:        %mkrel 1
Summary:        Tools for debugging the Intel graphics driver
Group:          System/Kernel and hardware
License:        MIT
URL:            https://gitlab.freedesktop.org/drm/igt-gpu-tools/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{tarname}-%{version}.tar.xz
# from upstream

BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  leg
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-xlib)
BuildRequires:  pkgconfig(dri2proto)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(libproc2)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmlrpc)
BuildRequires:  pkgconfig(xorg-macros)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  python3-docutils
BuildRequires:  python3

ExclusiveArch:  %ix86 x86_64

%description
Intel GPU Tools is a package of tools for debugging the Intel graphics
driver, including a GPU hang dumping program, performance monitor, and
performance microbenchmarks for regression testing the DRM.

%package devel
Summary:   Xorg X11 Intel video driver development package
Group:     Development/C
Requires:  %{name} = %{version}-%{release}
Provides:  xorg-x11-drv-intel-devel = %{version}-%{release}

%description devel
X.Org X11 Intel video driver development package.

%prep
%autosetup -p1 -n %{tarname}-%{version}

%build
%meson -Doverlay=enabled -Doping=disabled -Ddocs=disabled
%meson_build

%install
%meson_install

%files devel
%{_libdir}/pkgconfig/intel-gen4asm.pc
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/xe-oa.pc
%{_includedir}/xe-oa/
%{_libdir}/pkgconfig/i915-perf.pc
%{_includedir}/i915-perf/


%files
%doc NEWS README.md
%{_bindir}/amd_*
%{_bindir}/code_cov_*
%{_bindir}/igt_*
%{_bindir}/i915-perf*
%{_bindir}/intel*
%{_bindir}/dpcd_reg
%{_bindir}/msm_dp_compliance
%{_bindir}/lsgpu
%{_bindir}/gputop
%{_bindir}/power
%{_bindir}/xe-perf*
%{_datadir}/%{tarname}/
#{_datadir}/gtk-doc/html/igt-gpu-tools/
%{_libdir}/lib*.so.0
%{_libdir}/lib*.so.1.5
%{_libexecdir}/%{tarname}/
%{_mandir}/man1/intel*.1*


%changelog
* Fri Jan 24 2025 daviddavid <daviddavid> 1.30-1.mga10
+ Revision: 2141327
- new version: 1.30

* Sun Oct 20 2024 daviddavid <daviddavid> 1.29-1.mga10
+ Revision: 2108828
- new version: 1.29

* Mon Nov 06 2023 daviddavid <daviddavid> 1.28-2.mga10
+ Revision: 2004701
- disable gtk-doc for now
- rebuild for new procps 4.x

* Wed Sep 20 2023 daviddavid <daviddavid> 1.28-1.mga10
+ Revision: 1988745
- new version: 1.28

* Sat Jan 21 2023 daviddavid <daviddavid> 1.27.1-1.mga9
+ Revision: 1934708
- new version: 1.27.1

* Sat Jan 14 2023 daviddavid <daviddavid> 1.27-1.mga9
+ Revision: 1932873
- new version: 1.27
- enable overlay support (leg is now available)

* Thu Dec 29 2022 daviddavid <daviddavid> 1.26-4.mga9
+ Revision: 1927511
- rebuild for new gsl 2.7.1

* Fri Oct 28 2022 ghibo <ghibo> 1.26-3.mga9
+ Revision: 1899910
- Fix URL.
- Add a patch from upstream to fix meson building.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Nov 09 2021 tv <tv> 1.26-1.mga9
+ Revision: 1755135
- 1.26

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.25-2.mga8
+ Revision: 1650728
- rebuild for json-c
+ danf <danf>
- Switch URLs from http: to https:

* Sat Mar 21 2020 tv <tv> 1.25-1.mga8
+ Revision: 1558717
- 1.25

* Wed Feb 19 2020 umeabot <umeabot> 1.24-3.mga8
+ Revision: 1544377
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 1.24-2.mga8
+ Revision: 1482900
- rebuild for new procps-ng 3.3.16

* Mon Dec 02 2019 zezinho <zezinho> 1.24-1.mga8
+ Revision: 1464083
- new version 1.24

* Mon Jan 21 2019 luigiwalser <luigiwalser> 1.23-3.mga7
+ Revision: 1358529
- add patches from opensuse to hopefully fix build
+ daviddavid <daviddavid>
- rebuild for new procps 3.3.15

* Sun Sep 23 2018 umeabot <umeabot> 1.23-2.mga7
+ Revision: 1298303
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 tv <tv> 1.23-1.mga7
+ Revision: 1251479
- BR pkgconfig(libssl)
- new release
- upstream is now named igt-gpu-tools

* Wed Apr 04 2018 tv <tv> 1.22-2.mga7
+ Revision: 1215235
- split devel subpkg

* Mon Mar 12 2018 tv <tv> 1.22-1.mga7
+ Revision: 1208301
- new release
- add patches from FC

* Mon Feb 19 2018 tv <tv> 1.21-1.mga7
+ Revision: 1203290
- fix build
- new release
- new release

* Sat Jun 10 2017 akien <akien> 1.19-1.mga6
+ Revision: 1107522
- Version 1.19

* Mon Mar 13 2017 akien <akien> 1.18-1.mga6
+ Revision: 1092364
- Version 1.18

* Mon Dec 05 2016 akien <akien> 1.17-1.mga6
+ Revision: 1072625
- Version 1.17
+ ghibo <ghibo>
- Added glibc-static-devel to BuildRequires.

* Thu Nov 03 2016 akien <akien> 1.16-3.mga6
+ Revision: 1065042
- Add upstream patch to fix ix86 build

* Thu Nov 03 2016 akien <akien> 1.16-2.mga6
+ Revision: 1065036
- Do not build on arm, there seems to be no drm_intel there
- Disable building the test suite, we do not run it (driver tests, not the built tools)
- Workaround i586 build misconfiguration, needs to be looked into
- imported package intel-gpu-tools
+ ghibo <ghibo>
- Added gtk-doc devel to BuildRequires.

